@@ -10,8 +10,8 @@ class Addon():
 
     def exposedControls(self):
         return {
-            "shutdown": {
+            "restart": {
                 "type": "button",
                 "icon": "mdi:restart",
             }
-        }
\ No newline at end of file
+        }
